<template>
    <div class="system-add-gas-container">
        <el-dialog
            :title="state.title"
            v-model="state.isShowUserDialog"
            width="550px"
        >
            <el-form :model="state.setForm" size="default" ref="gasRef" :rules=" state.title == '修改' ?state.setFormRules:''" label-width="150px">
                <el-form-item label="预警名称:" prop="name">
                    <span>{{state.setForm.name}}</span>
                </el-form-item>
                <el-form-item label="连续超过阈值点数:" prop="threshold">
                    <el-input v-model.trim="state.setForm.threshold" :disabled="state.disabled"></el-input>
                </el-form-item>
            </el-form>
            <template #footer>
                <span class="dialog-footer">
                    <el-button @click="handleClose" size="default" v-if="!state.disabled">取 消</el-button>
                    <el-button type="primary"  @click="onSubmit" size="default">确 定</el-button>
                </span>
            </template>
        </el-dialog>
    </div>
</template>

<script setup lang="ts">
import {reactive, ref} from "vue";
import {SetState} from "/@/types/warning";
import { warningSetApi } from "/@/api/warningManage/warningSet";
import {ElMessage} from "element-plus/es";

const gasRef = ref();
const emit = defineEmits(["getSetData"]);
const state = reactive<SetState>({
    title: '',
    isShowUserDialog: false,
    disabled: false,
    setForm: {
        id: '',
        name: '',
        threshold: 0
    },
    setFormRules:{
        threshold: [{ required: true, message: '请填写连续超过阈值点数', trigger: 'blur' }],
    }
});
const openDialog = (type: string, value: any) => {
    state.isShowUserDialog = true;
    if (type === '查看') {
        state.disabled = true;
        state.title = '查看';
        state.setForm = JSON.parse(JSON.stringify(value));
    } else {
        state.disabled = false;
        state.title = '修改';
        state.setForm = JSON.parse(JSON.stringify(value));
    }
};
const onSubmit = async () => {

    if(state.title == '修改'){
        const valid = gasRef.value.validate();
        if(valid){
            const param = {
                id: state.setForm.id,
                threshold: state.setForm.threshold
            }
            let res = await warningSetApi().handelWarnSet(param);
            if(res.data.code == 100){
                ElMessage({
                    type: 'success',
                    message: '修改成功'
                });
            }else {
                ElMessage({
                    type: 'error',
                    message: res.data.msg
                });
            }
        }
        gasRef.value.clearValidate();
        state.isShowUserDialog = false;
        emit('getSetData');
    }else {
        state.isShowUserDialog = false;
        emit('getSetData');
    }
};

const handleClose = () => {
    gasRef.value.clearValidate();
    state.isShowUserDialog = false;
    emit('getSetData');
}

defineExpose({
    openDialog
});
</script>
<style scoped lang="scss">

</style>